@@ -1,5 +1,4 @@
-# TODO: skip if poetry is not available or add mark to test it explicitly
-
+from __future__ import annotations
 
 import email
 import re
@@ -10,15 +9,18 @@ import zipfile
 from dataclasses import dataclass
 from pathlib import Path
 from typing import Iterable
-from typing import Tuple
 
 import pytest
 import toml
 
+# TODO: skip if poetry is not available or add mark to test it explicitly
+
+
 pytestmark = pytest.mark.release
 
 NAME = "pytest-httpserver"
 NAME_UNDERSCORE = NAME.replace("-", "_")
+PY_MAX_VERSION = (3, 12)
 
 
 @pytest.fixture(scope="session")
@@ -44,7 +46,7 @@ class Wheel:
 
     def extract(self):
         with zipfile.ZipFile(self.path) as zf:
-            zf.extractall(self.wheel_out_dir)
+            zf.extractall(self.wheel_out_dir)  # noqa: S202
 
     def get_meta(self, version: str, name: str = NAME_UNDERSCORE) -> email.message.Message:
         metadata_path = self.wheel_out_dir.joinpath(f"{name}-{version}.dist-info", "METADATA")
@@ -64,7 +66,7 @@ class Sdist:
 
     def extract(self):
         with tarfile.open(self.path, mode="r:gz") as tf:
-            tf.extractall(self.sdist_out_dir)
+            tf.extractall(self.sdist_out_dir)  # noqa: S202
 
 
 @dataclass
@@ -103,37 +105,43 @@ def version(pyproject) -> str:
     return pyproject["tool"]["poetry"]["version"]
 
 
-def version_to_tuple(version: str) -> Tuple:
+def version_to_tuple(version: str) -> tuple:
     return tuple([int(x) for x in version.split(".")])
 
 
 def test_no_duplicate_classifiers(build: Build, pyproject):
     pyproject_meta = pyproject["tool"]["poetry"]
     wheel_meta = build.wheel.get_meta(version=pyproject_meta["version"])
-    classifiers = sorted(wheel_meta.get_all("Classifier"))
-    unique_classifiers = sorted(set(wheel_meta.get_all("Classifier")))
+    classifiers = wheel_meta.get_all("Classifier")
+    assert classifiers is not None
 
-    assert classifiers == unique_classifiers
+    sorted_classifiers = sorted(classifiers)
+    unique_classifiers = sorted(set(classifiers))
+
+    assert sorted_classifiers == unique_classifiers
 
 
 def test_python_version(build: Build, pyproject):
     pyproject_meta = pyproject["tool"]["poetry"]
     wheel_meta = build.wheel.get_meta(version=pyproject_meta["version"])
     python_dependency = pyproject_meta["dependencies"]["python"]
-    m = re.match(r">=(\d+\.\d+),<(\d+\.\d+)", python_dependency)
+    m = re.match(r">=(\d+\.\d+)", python_dependency)
     if m:
-        min_version, max_version = m.groups()
+        min_version, *_ = m.groups()
     else:
         raise ValueError(python_dependency)
 
     min_version_tuple = version_to_tuple(min_version)
-    max_version_tuple = version_to_tuple(max_version)
 
-    for classifier in wheel_meta.get_all("Classifier"):
+    classifiers = wheel_meta.get_all("Classifier")
+    assert classifiers is not None
+
+    for classifier in classifiers:
         if classifier.startswith("Programming Language :: Python ::"):
             version_tuple = version_to_tuple(classifier.split("::")[-1].strip())
             if len(version_tuple) > 1:
-                assert version_tuple >= min_version_tuple and version_tuple < max_version_tuple
+                assert version_tuple >= min_version_tuple
+                assert version_tuple <= PY_MAX_VERSION
 
 
 def test_wheel_no_extra_contents(build: Build, version: str):
@@ -147,6 +155,7 @@ def test_wheel_no_extra_contents(build: Build, version: str):
     assert package_contents == {
         "__init__.py",
         "blocking_httpserver.py",
+        "hooks.py",
         "httpserver.py",
         "py.typed",
         "pytest_plugin.py",
@@ -168,7 +177,6 @@ def test_sdist_contents(build: Build, version: str):
             "pyproject.toml",
             "pytest_httpserver",
             "README.md",
-            "setup.py",
             "tests",
         },
         "doc": {
@@ -182,12 +190,14 @@ def test_sdist_contents(build: Build, version: str):
             "howto.rst",
             "index.rst",
             "Makefile",
+            "patch.py",
             "tutorial.rst",
             "upgrade.rst",
         },
         "pytest_httpserver": {
             "__init__.py",
             "blocking_httpserver.py",
+            "hooks.py",
             "httpserver.py",
             "py.typed",
             "pytest_plugin.py",
@@ -199,8 +209,11 @@ def test_sdist_contents(build: Build, version: str):
             "test_blocking_httpserver.py",
             "test_handler_errors.py",
             "test_headers.py",
+            "test_hooks.py",
             "test_ip_protocols.py",
             "test_json_matcher.py",
+            "test_log_leak.py",
+            "test_log_querying.py",
             "test_mixed.py",
             "test_oneshot.py",
             "test_ordered.py",
@@ -211,6 +224,7 @@ def test_sdist_contents(build: Build, version: str):
             "test_querystring.py",
             "test_release.py",
             "test_ssl.py",
+            "test_threaded.py",
             "test_urimatch.py",
             "test_wait.py",
             "test_with_statement.py",
